# Debug Analysis of Test Failures

## Issues Identified

### 1. **Handshake Never Starts**
- Phone states show `IN_CALL` after answering
- But handshake is never initiated
- `handshake_complete` remains False for both phones

### 2. **Voice Session Never Starts**
- Since handshake doesn't complete, voice sessions can't start
- Audio files are never loaded
- Frame counters remain at 0

### 3. **Message Flow Issue**
- The log shows "Client 1 received raw: CALL_END" 
- This suggests premature disconnection

## Root Cause Analysis

The protocol flow should be:
1. Phone 1 calls Phone 2 → sends "RINGING"
2. Phone 2 answers → sends "IN_CALL"
3. Phone 1 receives "IN_CALL" → initiator starts handshake
4. Noise XK handshake completes
5. Both phones start voice sessions

The break appears to be at step 3 - the initiator check or message handling.

## Debugging Steps Added

1. **More verbose state logging** - Shows initiator status
2. **Command queue debugging** - Shows if handshake command is queued
3. **Wait step added** - Gives time for handshake to start
4. **All print → debug** - Cleaner console output

## Next Steps to Fix

1. **Check message routing** - Ensure IN_CALL triggers handshake for initiator
2. **Verify state management** - initiator flag must be properly set
3. **Check socket stability** - Why is CALL_END being sent?
4. **Add manual handshake trigger** - For testing purposes