# Debug Features in DryBox UI

## Overview

The DryBox UI now includes extensive debugging capabilities for testing and troubleshooting the integrated protocol stack (Noise XK + Codec2 + 4FSK + ChaCha20).

## Features

### 1. **Debug Console**
- Built-in debug console at the bottom of the UI
- Shows real-time protocol events and state changes
- Color-coded terminal-style output (green text on black)
- Auto-scrolls to show latest messages
- Resizable using splitter

### 2. **Automatic Test Button** 🧪
- Orange button that runs through complete protocol flow
- 10-step automated test sequence:
  1. Check initial state
  2. Make call (Phone 1 → Phone 2)
  3. Answer call (Phone 2)
  4. Verify Noise XK handshake
  5. Check voice session status
  6. Monitor audio transmission
  7. Display protocol stack details
  8. Wait for voice frames
  9. Show transmission statistics
  10. Hang up and cleanup
- Can be stopped at any time
- Shows detailed debug info at each step

### 3. **Debug Logging**

#### Console Output
All debug messages are printed to console with timestamps:
```
[HH:MM:SS.mmm] [Component] Message
```

#### UI Output
Same messages appear in the debug console within the UI

#### Components with Debug Logging:
- **PhoneManager**: Call setup, audio transmission, state changes
- **ProtocolPhoneClient**: Connection, handshake, voice frames
- **ProtocolClientState**: Command processing, state transitions
- **Main UI**: User actions, state updates

### 4. **Debug Information Displayed**

#### Connection Status
- GSM simulator connection state
- Socket status for each phone

#### Handshake Details
- Noise XK role (initiator/responder)
- Public keys (truncated for readability)
- Handshake completion status
- Session establishment

#### Voice Protocol
- Codec2 mode and parameters (1200 bps, 48 bits/frame)
- 4FSK frequencies (600, 1200, 1800, 2400 Hz)
- Frame encoding/decoding stats
- Encryption details (ChaCha20 key derivation)

#### Transmission Statistics
- Frame counters (logged every 25 frames/1 second)
- Audio timer status
- Waveform updates

### 5. **Usage**

#### Manual Testing
1. Click buttons to manually control calls
2. Watch debug console for protocol events
3. Monitor waveforms for audio activity

#### Automatic Testing
1. Click "🧪 Run Automatic Test"
2. Watch as system goes through complete flow
3. Review debug output for any issues
4. Click "⏹ Stop Test" to halt

#### Clear Debug
- Click "Clear Debug" to clear console
- Useful when starting fresh test

### 6. **Debug Message Examples**

```
[14:23:45.123] [PhoneManager] Initialized Phone 1 with public key: 5f46f046f6e9380d74aff8d4fa24196c...
[14:23:45.456] [Phone1] Connected to GSM simulator at localhost:12345
[14:23:46.789] [Phone1] Starting Noise XK handshake as initiator
[14:23:47.012] [Phone1] Noise XK handshake complete!
[14:23:47.234] [Phone1] Voice session started
[14:23:47.567] [Phone1] Encoding voice frame #0: 640 bytes PCM → 6 bytes compressed
[14:23:48.890] [Phone2] Received voice data frame #25
```

### 7. **Troubleshooting with Debug Info**

- **No connection**: Check "Connected to GSM simulator" messages
- **Handshake fails**: Look for public key exchanges and handshake steps
- **No audio**: Verify "Voice session started" and frame encoding
- **Poor quality**: Check FSK demodulation confidence scores

## Benefits

1. **Real-time Visibility**: See exactly what's happening in the protocol
2. **Easy Testing**: Automatic test covers all components
3. **Quick Debugging**: Identify issues without external tools
4. **Educational**: Understand protocol flow and timing
5. **Performance Monitoring**: Track frame rates and latency