# Testing Guide for DryBox Integrated Protocol

## Prerequisites

1. Install dependencies:
   ```bash
   pip3 install -r requirements.txt
   ```

2. Ensure GSM simulator is running:
   ```bash
   # Check if simulator is running
   netstat -an | grep 12345
   
   # If not running, start it:
   cd simulator
   python3 gsm_simulator.py
   ```

## Testing Options

### Option 1: GUI Test (Recommended)

Run the main DryBox UI with integrated protocol:

```bash
cd UI
python3 main.py
```

**How to use:**
1. The UI automatically connects both phones to the GSM simulator on startup
2. Click "Call" on Phone 1 to call Phone 2
3. Click "Answer" on Phone 2 to accept the call
4. The Noise XK handshake will start automatically
5. Watch the status change to "🔒 Secure Channel Established"
6. Voice transmission starts automatically using test audio
7. Watch the waveform displays showing transmitted/received audio
8. Status changes to "🎤 Voice Active (Encrypted)" during voice
9. Click "Hang Up" on either phone to end the call

### Option 2: Command Line Test

For automated testing without GUI:

```bash
python3 test_protocol_cli.py
```

This runs through the complete protocol flow automatically.


## What to Expect

When everything is working correctly:

1. **Connection Phase**: Both phones connect to the GSM simulator
2. **Call Setup**: Phone 1 calls Phone 2, you'll see "RINGING" state
3. **Handshake**: Noise XK handshake establishes secure channel
4. **Voice Session**: 
   - Audio is compressed with Codec2 (1200 bps)
   - Modulated with 4FSK (600 baud)
   - Encrypted with ChaCha20
   - Wrapped in Noise XK encryption
   - Transmitted over simulated GSM channel

## Verifying the Integration

Look for these indicators:
- ✓ "Handshake complete" message
- ✓ Waveform displays showing activity
- ✓ Log messages showing encryption/decryption
- ✓ Confidence scores >90% for demodulation

## Troubleshooting

1. **"Address already in use"**: GSM simulator already running
2. **"Module not found"**: Run `pip3 install -r requirements.txt`
3. **No audio**: Check if test wav files exist in `wav/` directory
4. **Connection refused**: Start the GSM simulator first

## Protocol Details

The integrated system implements:
- **Noise XK**: 3-message handshake pattern
- **Codec2**: 48 bits per 40ms frame at 1200 bps
- **4FSK**: Frequencies 600, 1200, 1800, 2400 Hz
- **ChaCha20**: 256-bit keys with 16-byte nonces
- **Dual encryption**: Noise session + per-frame ChaCha20