# UI Improvements Summary

## Fixed Issues

### 1. **AttributeError with symbol_rate**
- Changed `symbol_rate` to `baud_rate` (correct attribute name)
- FSKModem uses `baud_rate` not `symbol_rate`

### 2. **PhoneState Enum Error**
- Converted PhoneState from class with integers to proper Enum
- Fixed `.name` attribute errors in auto test
- Added fallback for both enum and integer states

### 3. **Window Resize on Fedora/Wayland**
- Added minimum window size (800x600)
- Created `run_ui.sh` script with proper Wayland support
- Set `QT_QPA_PLATFORM=wayland` environment variable

### 4. **Reduced Console Noise**
- Removed verbose initialization prints from Codec2 and FSKModem
- Converted most print statements to debug() method
- Removed per-chunk data logging
- Only log voice frames every 25 frames (1 second)

### 5. **Audio File Testing**
- Confirmed test uses `wav/input_8k_mono.wav`
- Added debug output to show when audio file is loaded
- Auto test now checks if audio files are loaded

## Debug Console Features

- **Automatic Test Button**: 10-step test sequence
- **Clear Debug Button**: Clear console output
- **Resizable Debug Console**: Using QSplitter
- **Timestamped Messages**: Format `[HH:MM:SS.mmm]`
- **Component Identification**: `[Phone1]`, `[PhoneManager]`, etc.

## What You'll See During Test

1. **Initial Connection**
   ```
   [09:52:01] [PhoneManager] Initialized Phone 1 with public key: 61e2779d...
   [09:52:01] [Phone1] Connected to GSM simulator at localhost:12345
   ```

2. **Call Setup**
   ```
   [09:52:03] [PhoneManager] Phone 1 initiating call to Phone 2
   [09:52:03] Phone 1 state change: RINGING
   ```

3. **Handshake**
   ```
   [09:52:05] [Phone1] Starting Noise XK handshake as initiator
   [09:52:05] [Phone1] Noise XK handshake complete!
   [09:52:05] [Phone1] Secure channel established
   ```

4. **Voice Session**
   ```
   [09:52:06] [PhoneManager] Phone 1 loaded test audio file: wav/input_8k_mono.wav
   [09:52:06] [Phone1] Voice session started
   [09:52:07] [Phone1] Encoding voice frame #0: 640 bytes PCM → 6 bytes compressed
   [09:52:08] [PhoneManager] Phone 1 sent 25 voice frames
   ```

5. **Protocol Details**
   ```
   [09:52:09] Codec mode: MODE_1200
   [09:52:09] Frame size: 48 bits
   [09:52:09] FSK frequencies: [600, 1200, 1800, 2400]
   [09:52:09] Symbol rate: 600 baud
   ```

## Running the UI

```bash
# With Wayland support
./run_ui.sh

# Or directly
cd UI
QT_QPA_PLATFORM=wayland python3 main.py
```

The UI is now cleaner, more informative, and properly handles all protocol components with extensive debugging capabilities.