# UI Modifications for Integrated Protocol

## Summary of Changes

The existing DryBox UI has been modified to use the integrated protocol (Noise XK + Codec2 + 4FSK + ChaCha20) instead of creating a new UI.

## Modified Files

### 1. `phone_manager.py`
- **Changed imports**: Now uses `ProtocolPhoneClient` instead of `PhoneClient`
- **Added audio file handling**: Loads and plays `wav/input_8k_mono.wav` for testing
- **Updated `send_audio()`**: 
  - Sends audio through the protocol stack (Codec2 → 4FSK → ChaCha20)
  - Handles 40ms frames (320 samples at 8kHz)
  - Updates waveform display
- **Enhanced `start_audio()`**: Starts voice sessions after handshake
- **Added cleanup**: Properly closes audio files and ends voice sessions

### 2. `main.py`
- **Updated window title**: Shows "DryBox - Noise XK + Codec2 + 4FSK + ChaCha20"
- **Added protocol info label**: Displays protocol stack information
- **Enhanced `set_phone_state()`**: 
  - Handles new protocol states: `HANDSHAKE_COMPLETE`, `VOICE_START`, `VOICE_END`
  - Shows secure channel status with lock emoji 🔒
  - Shows voice active status with microphone emoji 🎤

### 3. Protocol Integration
- Uses `ProtocolPhoneClient` which includes:
  - Noise XK handshake
  - Codec2 voice compression (1200 bps)
  - 4FSK modulation (600 baud)
  - ChaCha20 encryption for voice frames
  - Automatic voice session management

## How It Works

1. **Startup**: Both phones automatically connect to GSM simulator
2. **Call Setup**: Click "Call" → "Answer" establishes connection
3. **Security**: Automatic Noise XK handshake creates secure channel
4. **Voice**: 
   - Audio compressed with Codec2 (1200 bps, 48 bits/frame)
   - Modulated with 4FSK (frequencies: 600, 1200, 1800, 2400 Hz)
   - Encrypted with ChaCha20 (per-frame encryption)
   - Wrapped in Noise XK session encryption
5. **Display**: Real-time waveforms show sent/received audio

## Visual Indicators

- **"🔒 Secure Channel Established"**: Handshake complete
- **"🎤 Voice Active (Encrypted)"**: Voice transmission active
- **Waveforms**: Show audio activity in real-time

## Testing

Simply run:
```bash
cd UI
python3 main.py
```

The integrated protocol is now seamlessly part of the existing DryBox UI!