#!/usr/bin/env python3
"""Clean test without ChaCha20"""

import sys
import time
sys.path.append('UI')
from PyQt5.QtWidgets import QApplication
from PyQt5.QtCore import QTimer
from main import PhoneUI

def main():
    app = QApplication(sys.argv)
    window = PhoneUI()
    
    # Suppress debug output during test
    error_count = 0
    success_count = 0
    
    original_debug = window.debug
    def count_debug(msg):
        nonlocal error_count, success_count
        if "Decryption error:" in msg:
            error_count += 1
        elif "Received voice data frame" in msg:
            success_count += 1
        # Only show important messages
        if any(x in msg for x in ["handshake complete!", "Voice session", "Starting audio"]):
            original_debug(msg)
    
    window.debug = count_debug
    window.show()
    
    print("\n=== CLEAN TEST - NO CHACHA20 ===\n")
    
    # Make call
    QTimer.singleShot(1000, lambda: test_sequence())
    
    def test_sequence():
        print("1. Making call...")
        window.manager.phone_action(0, window)
        
        QTimer.singleShot(1000, lambda: answer_call())
    
    def answer_call():
        print("2. Answering call...")
        window.manager.phone_action(1, window)
        
        QTimer.singleShot(10000, lambda: show_results())
    
    def show_results():
        phone1 = window.manager.phones[0]
        phone2 = window.manager.phones[1]
        
        print(f"\n3. Results after 10 seconds:")
        print(f"   Handshake: P1={phone1['client'].handshake_complete}, P2={phone2['client'].handshake_complete}")
        print(f"   Voice: P1={phone1['client'].voice_active}, P2={phone2['client'].voice_active}")
        print(f"   Sent: P1={phone1.get('frame_counter', 0)}, P2={phone2.get('frame_counter', 0)}")
        print(f"   Received: P1={phone1['client'].voice_frame_counter}, P2={phone2['client'].voice_frame_counter}")
        print(f"   Decryption errors: {error_count}")
        print(f"   Voice frames decoded: {success_count}")
        
        if error_count == 0 and success_count > 0:
            print(f"\n✅ SUCCESS! Protocol working without ChaCha20!")
        elif error_count > 0:
            print(f"\n❌ Still getting decryption errors")
        else:
            print(f"\n❌ No voice frames received")
        
        app.quit()
    
    sys.exit(app.exec_())

if __name__ == "__main__":
    main()