#!/usr/bin/env python3
"""Test without ChaCha20 encryption"""

import sys
import time
sys.path.append('UI')
from PyQt5.QtWidgets import QApplication
from PyQt5.QtCore import QTimer
from main import PhoneUI

def main():
    app = QApplication(sys.argv)
    window = PhoneUI()
    window.show()
    
    print("\n=== TESTING WITHOUT CHACHA20 ===")
    print("Using only Noise XK encryption for everything\n")
    
    # Run auto test
    QTimer.singleShot(1000, lambda: window.auto_test_button.click())
    
    # Monitor progress
    def check_progress():
        phone1 = window.manager.phones[0]
        phone2 = window.manager.phones[1]
        
        if phone1['client'].handshake_complete and phone2['client'].handshake_complete:
            print("✓ Handshake completed for both phones")
            if phone1['client'].voice_active and phone2['client'].voice_active:
                print("✓ Voice sessions active")
                frames1 = phone1.get('frame_counter', 0)
                frames2 = phone2.get('frame_counter', 0)
                print(f"  Phone 1 sent {frames1} frames")
                print(f"  Phone 2 sent {frames2} frames")
    
    # Check every 2 seconds
    progress_timer = QTimer()
    progress_timer.timeout.connect(check_progress)
    progress_timer.start(2000)
    
    # Final results after 20 seconds
    def final_results():
        progress_timer.stop()
        
        phone1 = window.manager.phones[0]
        phone2 = window.manager.phones[1]
        
        console_text = window.debug_console.toPlainText()
        
        print("\n=== FINAL RESULTS ===")
        print(f"Handshake: P1={phone1['client'].handshake_complete}, P2={phone2['client'].handshake_complete}")
        print(f"Voice Active: P1={phone1['client'].voice_active}, P2={phone2['client'].voice_active}")
        print(f"Frames Sent: P1={phone1.get('frame_counter', 0)}, P2={phone2.get('frame_counter', 0)}")
        print(f"Frames Received: P1={phone1['client'].voice_frame_counter}, P2={phone2['client'].voice_frame_counter}")
        
        # Count errors and successes
        decrypt_errors = console_text.count("Decryption error")
        voice_decode_errors = console_text.count("Voice decode error")
        received_voice = console_text.count("Received voice data frame")
        
        print(f"\nDecryption errors: {decrypt_errors}")
        print(f"Voice decode errors: {voice_decode_errors}")
        print(f"Voice frames successfully received: {received_voice}")
        
        # Success criteria
        if (decrypt_errors == 0 and 
            phone1['client'].voice_frame_counter > 10 and 
            phone2['client'].voice_frame_counter > 10):
            print("\n✅ SUCCESS! No ChaCha20 = No decryption errors!")
        else:
            print("\n❌ Still having issues...")
        
        app.quit()
    
    QTimer.singleShot(20000, final_results)
    
    sys.exit(app.exec_())

if __name__ == "__main__":
    main()