#!/usr/bin/env python3
"""Test UI fixes - waveforms and layout"""

import sys
import time
sys.path.append('UI')
from PyQt5.QtWidgets import QApplication
from PyQt5.QtCore import QTimer
from main import PhoneUI

def main():
    app = QApplication(sys.argv)
    window = PhoneUI()
    
    # Track waveform updates
    waveform_updates = {'sent': 0, 'received': 0}
    
    original_update_waveform = window.manager.update_waveform
    original_update_sent = window.manager.update_sent_waveform
    
    def track_received(client_id, data):
        waveform_updates['received'] += 1
        original_update_waveform(client_id, data)
        if waveform_updates['received'] == 1:
            print("✓ First received waveform update")
    
    def track_sent(client_id, data):
        waveform_updates['sent'] += 1
        original_update_sent(client_id, data)
        if waveform_updates['sent'] == 1:
            print("✓ First sent waveform update")
    
    window.manager.update_waveform = track_received
    window.manager.update_sent_waveform = track_sent
    
    window.show()
    
    print("\n=== UI FIXES TEST ===")
    print("1. Window title updated (no ChaCha20)")
    print("2. Waveform widgets properly sized")
    print("3. Layout more compact")
    print("")
    
    # Test sequence
    def start_test():
        print("Starting call test...")
        window.manager.phone_action(0, window)
        QTimer.singleShot(1000, answer_call)
    
    def answer_call():
        print("Answering call...")
        window.manager.phone_action(1, window)
        QTimer.singleShot(5000, check_results)
    
    def check_results():
        print(f"\nWaveform updates:")
        print(f"  Sent: {waveform_updates['sent']}")
        print(f"  Received: {waveform_updates['received']}")
        
        if waveform_updates['sent'] > 0 and waveform_updates['received'] > 0:
            print("\n✅ Waveforms updating correctly!")
        else:
            print("\n⚠️  Waveforms may not be updating")
            
        print("\nCheck the UI visually:")
        print("- Waveforms should show audio activity")
        print("- Layout should be properly sized")
        print("- No overlapping elements")
        
        # Keep window open for visual inspection
        QTimer.singleShot(5000, app.quit)
    
    QTimer.singleShot(1000, start_test)
    sys.exit(app.exec_())

if __name__ == "__main__":
    main()