#!/usr/bin/env python3
"""Debug script to trace the UI behavior"""

import sys
from pathlib import Path

# Monkey patch the integrated_protocol to see what's being called
orig_file = Path(__file__).parent / "DryBox" / "integrated_protocol.py"
backup_file = Path(__file__).parent / "DryBox" / "integrated_protocol_backup.py"

# Read the original file
with open(orig_file, 'r') as f:
    content = f.read()

# Add debug prints
debug_content = content.replace(
    'def initiate_key_exchange(self, cipher_type=1, is_initiator=True):',
    '''def initiate_key_exchange(self, cipher_type=1, is_initiator=True):
        import traceback
        print(f"\\n[DEBUG] initiate_key_exchange called with is_initiator={is_initiator}")
        print("[DEBUG] Call stack:")
        for line in traceback.format_stack()[:-1]:
            print(line.strip())
        print()'''
)

# Write the debug version
with open(orig_file, 'w') as f:
    f.write(debug_content)

print("Debug patch applied. Run the UI now to see the trace.")
print("To restore: cp DryBox/integrated_protocol_backup.py DryBox/integrated_protocol.py")